@@ -207,7 +207,8 @@ oath_bin2hex (const char *binstr, size_t binlen, char *hexstr)
 int
 oath_base32_decode (const char *in, size_t inlen, char **out, size_t *outlen)
 {
-  size_t i, j, tmplen = 0;
+  size_t i, j;
+  idx_t tmplen = 0;
   char *in_upcase;
   char *tmp;
   bool ok;
