@@ -1,6 +1,6 @@
 #!/bin/sh
 # tst_usersfile.sh - Invoke tst_usersfile and check output.
-# Copyright (C) 2009-2021 Simon Josefsson
+# Copyright (C) 2009-2023 Simon Josefsson
 
 # This library is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as
@@ -22,15 +22,20 @@ srcdir=${srcdir:-.}
 TZ=UTC
 export TZ
 
-TSTAMP=`datefudge "2006-09-23" date -u +%s`
+FAKETIME=datefudge
+TSTAMP=`$FAKETIME "2006-09-23" date -u +%s`
 if test "$TSTAMP" != "1158969600"; then
-    echo "Could not fake timestamps with datefudge."
-    exit 77
+    FAKETIME=faketime
+    TSTAMP=`$FAKETIME "2006-09-23" date -u +%s`
+    if test "$TSTAMP" != "1158969600"; then
+	echo "Faketime or datefudge missing ($TSTAMP)" >&2
+	exit 77
+    fi
 fi
 
 cp $srcdir/users.oath tmp.oath
 
-datefudge 2006-12-07 ./tst_usersfile$EXEEXT
+$FAKETIME 2006-12-07 ./tst_usersfile$EXEEXT
 rc=$?
 sed 's/2006-12-07T00:00:0.L/2006-12-07T00:00:00L/g' < tmp.oath > tmp2.oath
 diff -ur $srcdir/expect.oath tmp2.oath || rc=1
