@@ -1,6 +1,6 @@
 /*
  * test-pam_oath.c - self-tests for PAM module for OATH one-time passwords
- * Copyright (C) 2009-2021 Simon Josefsson
+ * Copyright (C) 2009-2023 Simon Josefsson
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,13 +27,16 @@
 #define PAM_SM_AUTH
 #include <security/pam_modules.h>
 
+/* pam_strerror */
+#include <security/pam_appl.h>
+
 int
 main (int argc, char **argv)
 {
   pam_handle_t *pamh = NULL;
   int rc;
 
-  rc = pam_sm_authenticate (pamh, 0, 1, (const char **) argv);
+  rc = pam_sm_authenticate (pamh, 0, argc - 1, (const char **) argv + 1);
 
   printf ("rc %d: %s\n", rc, pam_strerror (pamh, rc));
 
